set ::sprite_data [list \
  download_manager_hover 0 0 51 41 \
  download_manager_press 0 41 51 41 \
  download_manager_rest 51 0 51 41 \
  language_options_hover 51 41 51 41 \
  language_options_press 0 82 51 41 \
  language_options_rest 51 82 51 41 \
  search_options_hover 102 0 51 41 \
  search_options_press 102 41 51 41 \
  search_options_rest 102 82 51 41 \
  subsearch_options_hover 0 123 51 41 \
  subsearch_options_press 51 123 51 41 \
  subsearch_options_rest 102 123 51 41 \
  card 153 0 50 50 \
  btn_disabled 153 50 22 35 \
  btn_hover 175 50 22 35 \
  btn_pressed 153 85 22 35 \
  btn_rest 175 85 22 35 \
  subsearch 153 120 24 24 \
  scale_thumb_disabled 177 120 22 22 \
  scale_thumb_hover 177 142 22 22 \
  scale_thumb_pressed 0 164 22 22 \
  scale_thumb_rest 22 164 22 22 \
  scale_trough_hor 44 164 22 22 \
  scale_trough_vert 66 164 22 22 \
  check_disabled 88 164 20 20 \
  check_hover 108 164 20 20 \
  check_pressed 128 164 20 20 \
  check_rest 148 164 20 20 \
  check_tri_disabled 153 144 20 20 \
  check_tri_hover 168 164 20 20 \
  check_tri_pressed 0 186 20 20 \
  check_tri_rest 20 186 20 20 \
  check_unsel_disabled 40 186 20 20 \
  check_unsel_hover 60 186 20 20 \
  check_unsel_pressed 80 186 20 20 \
  check_unsel_rest 100 184 20 20 \
  scroll_hor_thumb 120 184 20 12 \
  scroll_hor_trough 140 184 20 12 \
  scroll_vert_thumb 160 184 10 20 \
  scroll_vert_trough 170 184 12 20 \
  textbox_dis 182 184 20 20 \
  textbox_error 188 164 20 20 \
  textbox_focus 203 0 20 20 \
  textbox_hover 203 20 20 20 \
  textbox_rest 203 40 20 20 \
  sizegrip 120 196 10 10 \
  scroll_down 130 196 8 6 \
  scroll_left 197 50 6 8 \
  scroll_right 197 58 6 8 \
  scroll_up 138 196 8 6 \
  separator 88 184 1 1 \
]
